@@ -250,17 +250,19 @@ static void loadOptions(ValueFederate* fed, const Inp& data, Obj& objUpdate)
 void ValueFederate::registerValueInterfacesJson(const std::string& jsonString)
 {
     auto doc = fileops::loadJson(jsonString);
-    registerValueInterfacesJsonDetail(doc, false);
+    registerValueInterfacesJsonDetail(fileops::JsonBuffer(doc), false);
 }
 
-void ValueFederate::registerValueInterfacesJsonDetail(Json::Value& json, bool defaultGlobal)
+void ValueFederate::registerValueInterfacesJsonDetail(const fileops::JsonBuffer& jsonBuff,
+                                                      bool defaultGlobal)
 {
+    const auto& json = jsonBuff.json();
     fileops::replaceIfMember(json, "defaultglobal", defaultGlobal);
 
-    Json::Value& iface = (json.isMember("interfaces")) ? json["interfaces"] : json;
+    const nlohmann::json& iface = (json.contains("interfaces")) ? json["interfaces"] : json;
 
-    if (iface.isMember("publications")) {
-        auto pubs = iface["publications"];
+    if (iface.contains("publications")) {
+        const auto& pubs = iface["publications"];
         for (const auto& pub : pubs) {
             auto name = fileops::getName(pub);
 
@@ -285,8 +287,8 @@ void ValueFederate::registerValueInterfacesJsonDetail(Json::Value& json, bool de
             addTargetVariations(pub, "destination", "targets", addDestTarget);
         }
     }
-    if (iface.isMember("subscriptions")) {
-        auto& subs = iface["subscriptions"];
+    if (iface.contains("subscriptions")) {
+        const auto& subs = iface["subscriptions"];
         for (const auto& sub : subs) {
             bool skipNameTarget{false};
             auto name = fileops::getName(sub);
@@ -317,8 +319,8 @@ void ValueFederate::registerValueInterfacesJsonDetail(Json::Value& json, bool de
             addTargetVariations(sub, "source", "targets", addSourceTarget);
         }
     }
-    if (iface.isMember("inputs")) {
-        auto ipts = iface["inputs"];
+    if (iface.contains("inputs")) {
+        const auto& ipts = iface["inputs"];
         for (const auto& ipt : ipts) {
             auto name = fileops::getName(ipt);
 
@@ -347,7 +349,7 @@ void ValueFederate::registerValueInterfacesJsonDetail(Json::Value& json, bool de
         }
     }
 
-    if (json.isMember("helics")) {
+    if (json.contains("helics")) {
         registerValueInterfacesJsonDetail(json["helics"], defaultGlobal);
     }
 }
@@ -436,7 +438,7 @@ void ValueFederate::registerValueInterfacesToml(const std::string& tomlString)
         }
     }
     if (isMember(doc, "inputs")) {
-        auto ipts = toml::find(doc, "inputs");
+        auto& ipts = toml::find(doc, "inputs");
         if (!ipts.is_array()) {
             throw(helics::InvalidParameter(
                 "inputs section in toml file must be an array"));  // LCOV_EXCL_LINE
@@ -494,17 +496,17 @@ using dvalue = std::variant<double, std::string>;
 static void generateData(std::vector<std::pair<std::string, dvalue>>& vpairs,
                          const std::string& prefix,
                          char separator,
-                         Json::Value val)
+                         const nlohmann::json& val)
 {
-    for (auto& name : val.getMemberNames()) {
-        auto& field = val[name];
-        if (field.isObject()) {
-            generateData(vpairs, prefix + name + separator, separator, field);
+    for (const auto& item : val.items()) {
+        const auto& field = item.value();
+        if (field.is_object()) {
+            generateData(vpairs, prefix + item.key() + separator, separator, field);
         } else {
-            if (field.isDouble()) {
-                vpairs.emplace_back(prefix + name, field.asDouble());
+            if (field.is_number()) {
+                vpairs.emplace_back(prefix + item.key(), field.get<double>());
             } else {
-                vpairs.emplace_back(prefix + name, field.asString());
+                vpairs.emplace_back(prefix + item.key(), field.get<std::string>());
             }
         }
     }
