@@ -11,6 +11,10 @@ SPDX-License-Identifier: BSD-3-Clause
 #include "helicsVersion.hpp"
 
 #include <iostream>
+#include <memory>
+#include <string>
+#include <utility>
+#include <vector>
 
 namespace helics {
 
