@@ -5,17 +5,24 @@ additional details. All rights reserved.
 SPDX-License-Identifier: BSD-3-Clause
 */
 
+#include "../application_api/FederateInfo.hpp"
+#include "../core/CoreTypes.hpp"
 #include "../core/core-exceptions.hpp"
 #include "../core/coreTypeOperations.hpp"
 #include "../helics.hpp"
+#include "api-data.h"
 #include "gmlc/concurrency/TripWire.hpp"
+#include "helics/helics_enums.h"
 #include "helicsCallbacks.h"
 #include "helicsCore.h"
 #include "internal/api_objects.h"
 
 #include <iostream>
 #include <map>
+#include <memory>
 #include <mutex>
+#include <string>
+#include <utility>
 #include <vector>
 
 /** this is a random identifier put in place when the federate or core or broker gets created*/
@@ -175,7 +182,7 @@ HelicsFederateInfo helicsCreateFederateInfo()
 
 static constexpr const char* invalidFedInfoString = "helics Federate info object was not valid";
 
-static helics::FederateInfo* getFedInfo(HelicsFederateInfo fedInfo, HelicsError* err)
+helics::FederateInfo* getFedInfo(HelicsFederateInfo fedInfo, HelicsError* err)
 {
     if ((err != nullptr) && (err->error_code != 0)) {
         return nullptr;
@@ -454,188 +461,170 @@ void helicsFederateInfoSetIntegerProperty(HelicsFederateInfo fedInfo, int intege
     info->setProperty(integerProperty, propertyValue);
 }
 
+HelicsFederate generateNewHelicsFederateObject(std::shared_ptr<helics::Federate> fed, helics::FederateType type)
+{
+    auto fedI = std::make_unique<helics::FedObject>();
+    fedI->fedptr = std::move(fed);
+    fedI->type = type;
+    fedI->valid = fedValidationIdentifier;
+    auto* hfed = reinterpret_cast<HelicsFederate>(fedI.get());
+    getMasterHolder()->addFed(std::move(fedI));
+    return (hfed);
+}
+
 /* Creation and destruction of Federates */
 HelicsFederate helicsCreateValueFederate(const char* fedName, HelicsFederateInfo fedInfo, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
 
+    std::shared_ptr<helics::Federate> fed;
     try {
         if (fedInfo == nullptr) {
-            FedI->fedptr = std::make_shared<helics::ValueFederate>(AS_STRING(fedName), helics::FederateInfo());
+            fed = std::make_shared<helics::ValueFederate>(AS_STRING(fedName), helics::FederateInfo());
         } else {
             auto* info = getFedInfo(fedInfo, err);
             if (info == nullptr) {
                 return nullptr;
             }
-            FedI->fedptr = std::make_shared<helics::ValueFederate>(AS_STRING(fedName), *info);
+            fed = std::make_shared<helics::ValueFederate>(AS_STRING(fedName), *info);
         }
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
-    FedI->type = helics::FederateType::VALUE;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::VALUE);
 }
 
 HelicsFederate helicsCreateValueFederateFromConfig(const char* configFile, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    CHECK_NULL_STRING(configFile, nullptr);
+    std::shared_ptr<helics::Federate> fed;
     try {
-        FedI->fedptr = std::make_shared<helics::ValueFederate>(AS_STRING(configFile));
+        fed = std::make_shared<helics::ValueFederate>(AS_STRING(configFile));
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
-    FedI->type = helics::FederateType::VALUE;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::VALUE);
 }
 
 /* Creation and destruction of Federates */
 HelicsFederate helicsCreateMessageFederate(const char* fedName, HelicsFederateInfo fedInfo, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    std::shared_ptr<helics::Federate> fed;
     try {
         if (fedInfo == nullptr) {
-            FedI->fedptr = std::make_shared<helics::MessageFederate>(AS_STRING(fedName), helics::FederateInfo());
+            fed = std::make_shared<helics::MessageFederate>(AS_STRING(fedName), helics::FederateInfo());
         } else {
             auto* info = getFedInfo(fedInfo, err);
             if (info == nullptr) {
                 return nullptr;
             }
-            FedI->fedptr = std::make_shared<helics::MessageFederate>(AS_STRING(fedName), *info);
+            fed = std::make_shared<helics::MessageFederate>(AS_STRING(fedName), *info);
         }
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
-    FedI->type = helics::FederateType::MESSAGE;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::MESSAGE);
 }
 
 HelicsFederate helicsCreateMessageFederateFromConfig(const char* configFile, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    CHECK_NULL_STRING(configFile, nullptr);
+    std::shared_ptr<helics::Federate> fed;
 
     try {
-        FedI->fedptr = std::make_shared<helics::MessageFederate>(AS_STRING(configFile));
+        fed = std::make_shared<helics::MessageFederate>(AS_STRING(configFile));
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
-    FedI->type = helics::FederateType::MESSAGE;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::MESSAGE);
 }
 
 /* Creation and destruction of Federates */
 HelicsFederate helicsCreateCombinationFederate(const char* fedName, HelicsFederateInfo fedInfo, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    std::shared_ptr<helics::Federate> fed;
     try {
         if (fedInfo == nullptr) {
-            FedI->fedptr = std::make_shared<helics::CombinationFederate>(AS_STRING(fedName), helics::FederateInfo());
+            fed = std::make_shared<helics::CombinationFederate>(AS_STRING(fedName), helics::FederateInfo());
         } else {
             auto* info = getFedInfo(fedInfo, err);
             if (info == nullptr) {
                 return nullptr;
             }
-            FedI->fedptr = std::make_shared<helics::CombinationFederate>(AS_STRING(fedName), *info);
+            fed = std::make_shared<helics::CombinationFederate>(AS_STRING(fedName), *info);
         }
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
-    FedI->type = helics::FederateType::COMBINATION;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::COMBINATION);
 }
 
 HelicsFederate helicsCreateCombinationFederateFromConfig(const char* configFile, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    CHECK_NULL_STRING(configFile, nullptr);
+    std::shared_ptr<helics::Federate> fed;
     try {
-        FedI->fedptr = std::make_shared<helics::CombinationFederate>(AS_STRING(configFile));
+        fed = std::make_shared<helics::CombinationFederate>(AS_STRING(configFile));
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
 
-    FedI->type = helics::FederateType::COMBINATION;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::COMBINATION);
 }
 
 /* Creation and destruction of Federates */
 HelicsFederate helicsCreateCallbackFederate(const char* fedName, HelicsFederateInfo fedInfo, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    std::shared_ptr<helics::Federate> fed;
     try {
         if (fedInfo == nullptr) {
-            FedI->fedptr = std::make_shared<helics::CallbackFederate>(AS_STRING(fedName), helics::FederateInfo());
+            fed = std::make_shared<helics::CallbackFederate>(AS_STRING(fedName), helics::FederateInfo());
         } else {
             auto* info = getFedInfo(fedInfo, err);
             if (info == nullptr) {
                 return nullptr;
             }
-            FedI->fedptr = std::make_shared<helics::CallbackFederate>(AS_STRING(fedName), *info);
+            fed = std::make_shared<helics::CallbackFederate>(AS_STRING(fedName), *info);
         }
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
-    FedI->type = helics::FederateType::CALLBACK;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::CALLBACK);
 }
 
 HelicsFederate helicsCreateCallbackFederateFromConfig(const char* configFile, HelicsError* err)
 {
     HELICS_ERROR_CHECK(err, nullptr);
-    auto FedI = std::make_unique<helics::FedObject>();
+    std::shared_ptr<helics::Federate> fed;
     try {
-        FedI->fedptr = std::make_shared<helics::CallbackFederate>(AS_STRING(configFile));
+        fed = std::make_shared<helics::CallbackFederate>(AS_STRING(configFile));
     }
     catch (...) {
         helicsErrorHandler(err);
         return nullptr;
     }
 
-    FedI->type = helics::FederateType::CALLBACK;
-    FedI->valid = fedValidationIdentifier;
-    auto* fed = reinterpret_cast<HelicsFederate>(FedI.get());
-    getMasterHolder()->addFed(std::move(FedI));
-    return (fed);
+    return generateNewHelicsFederateObject(std::move(fed), helics::FederateType::CALLBACK);
 }
 
 HelicsFederate helicsFederateClone(HelicsFederate fed, HelicsError* err)
@@ -644,14 +633,7 @@ HelicsFederate helicsFederateClone(HelicsFederate fed, HelicsError* err)
     if (fedObj == nullptr) {
         return nullptr;
     }
-    auto fedClone = std::make_unique<helics::FedObject>();
-    fedClone->fedptr = fedObj->fedptr;
-
-    fedClone->type = fedObj->type;
-    fedClone->valid = fedValidationIdentifier;
-    auto* fedB = reinterpret_cast<HelicsFederate>(fedClone.get());
-    getMasterHolder()->addFed(std::move(fedClone));
-    return (fedB);
+    return generateNewHelicsFederateObject(fedObj->fedptr, fedObj->type);
 }
 
 HelicsFederate helicsGetFederateByName(const char* fedName, HelicsError* err)
@@ -675,14 +657,7 @@ HelicsFederate helicsGetFederateByName(const char* fedName, HelicsError* err)
         }
         return nullptr;
     }
-    auto fedClone = std::make_unique<helics::FedObject>();
-    fedClone->fedptr = fed->fedptr;
-
-    fedClone->type = fed->type;
-    fedClone->valid = fedValidationIdentifier;
-    auto* fedB = reinterpret_cast<HelicsFederate>(fedClone.get());
-    getMasterHolder()->addFed(std::move(fedClone));
-    return (fedB);
+    return generateNewHelicsFederateObject(fed->fedptr, fed->type);
 }
 
 void helicsFederateProtect(const char* fedName, HelicsError* err)
@@ -978,7 +953,8 @@ void helicsFederateEnterExecutingMode(HelicsFederate fed, HelicsError* err)
     }
 }
 
-static helics::IterationRequest getIterationRequest(HelicsIterationRequest iterate)
+namespace {
+helics::IterationRequest getIterationRequest(HelicsIterationRequest iterate)
 {
     switch (iterate) {
         case HELICS_ITERATION_REQUEST_NO_ITERATION:
@@ -996,7 +972,7 @@ static helics::IterationRequest getIterationRequest(HelicsIterationRequest itera
     }
 }
 
-static HelicsIterationResult getIterationStatus(helics::IterationResult iterationState)
+HelicsIterationResult getIterationStatus(helics::IterationResult iterationState)
 {
     switch (iterationState) {
         case helics::IterationResult::NEXT_STEP:
@@ -1011,7 +987,7 @@ static HelicsIterationResult getIterationStatus(helics::IterationResult iteratio
             return HELICS_ITERATION_RESULT_HALTED;
     }
 }
-
+}  // namespace
 HelicsIterationResult helicsFederateEnterExecutingModeIterative(HelicsFederate fed, HelicsIterationRequest iterate, HelicsError* err)
 {
     auto* fedObj = getFed(fed, err);
@@ -1245,10 +1221,12 @@ void helicsFederateProcessCommunications(HelicsFederate fed, HelicsTime period,
     }
 }
 
-static HelicsFederateState stateConversion(helics::Federate::Modes mode)
+namespace {
+HelicsFederateState stateConversion(helics::Federate::Modes mode)
 {
     return static_cast<HelicsFederateState>(static_cast<int32_t>(static_cast<std::underlying_type<helics::Federate::Modes>::type>(mode)));
 }
+}  // namespace
 
 HelicsFederateState helicsFederateGetState(HelicsFederate fed, HelicsError* err)
 {
