@@ -23,7 +23,9 @@ SPDX-License-Identifier: BSD-3-Clause
 #include <future>
 #include <iostream>
 #include <numeric>
+#include <string>
 #include <thread>
+#include <vector>
 
 /** these test cases test out the message federates
  */
@@ -512,6 +514,10 @@ TEST_F(mfed_tests, endpoint_linking_dest_unknown)
 {
     SetupTest<helics::CombinationFederate>("testA", 1, 1.0);
     auto mFed1 = GetFederateAs<helics::CombinationFederate>(0);
+    EXPECT_TRUE(mFed1);
+    if (!mFed1) {
+        return;
+    }
     helics::CoreApp core(mFed1->getCorePointer());
     auto& ept1 = mFed1->registerGlobalTargetedEndpoint("source_endpoint");
     core->linkEndpoints("source_endpoint", "dest_endpoint");
@@ -530,6 +536,10 @@ TEST_F(mfed_tests, endpoint_linking_source_unknown)
 {
     SetupTest<helics::CombinationFederate>("testA", 1, 1.0);
     auto mFed1 = GetFederateAs<helics::CombinationFederate>(0);
+    EXPECT_TRUE(mFed1);
+    if (!mFed1) {
+        return;
+    }
     helics::CoreApp core(mFed1->getCorePointer());
     auto& ept2 = mFed1->registerGlobalTargetedEndpoint("dest_endpoint");
     core->linkEndpoints("source_endpoint", "dest_endpoint");
@@ -548,6 +558,10 @@ TEST_F(mfed_tests, endpoint_linking_both_unknown)
 {
     SetupTest<helics::CombinationFederate>("testA", 1, 1.0);
     auto mFed1 = GetFederateAs<helics::CombinationFederate>(0);
+    EXPECT_TRUE(mFed1);
+    if (!mFed1) {
+        return;
+    }
     helics::CoreApp core(mFed1->getCorePointer());
 
     core->linkEndpoints("source_endpoint", "dest_endpoint");
@@ -567,6 +581,10 @@ TEST_F(mfed_tests, endpoint_linking_source_alias)
 {
     SetupTest<helics::CombinationFederate>("testA", 1, 1.0);
     auto mFed1 = GetFederateAs<helics::CombinationFederate>(0);
+    EXPECT_TRUE(mFed1);
+    if (!mFed1) {
+        return;
+    }
     helics::CoreApp core(mFed1->getCorePointer());
 
     core->linkEndpoints("source", "dest_endpoint");
@@ -587,6 +605,10 @@ TEST_F(mfed_tests, endpoint_linking_dest_alias)
 {
     SetupTest<helics::CombinationFederate>("testA", 1, 1.0);
     auto mFed1 = GetFederateAs<helics::CombinationFederate>(0);
+    EXPECT_TRUE(mFed1);
+    if (!mFed1) {
+        return;
+    }
     helics::CoreApp core(mFed1->getCorePointer());
 
     core->linkEndpoints("source_endpoint", "dest");
@@ -607,6 +629,10 @@ TEST_F(mfed_tests, endpoint_linking_dest_alias_rev)
 {
     SetupTest<helics::CombinationFederate>("testA", 1, 1.0);
     auto mFed1 = GetFederateAs<helics::CombinationFederate>(0);
+    EXPECT_TRUE(mFed1);
+    if (!mFed1) {
+        return;
+    }
     helics::CoreApp core(mFed1->getCorePointer());
 
     core->linkEndpoints("source_endpoint", "dest");
