@@ -17,7 +17,11 @@ SPDX-License-Identifier: BSD-3-Clause
 #include <gmock/gmock.h>
 #include <gtest/gtest.h>
 #include <iostream>
+#include <memory>
+#include <string>
 #include <thread>
+#include <utility>
+#include <vector>
 
 /** these test cases test out the message federates
  */
@@ -60,24 +64,24 @@ TEST_F(mfed_tests, endpoint_registration)
     SetupTest<helics::MessageFederate>("test", 1);
     auto mFed1 = GetFederateAs<helics::MessageFederate>(0);
 
-    auto& epid = mFed1->registerEndpoint("ep1");
-    auto& epid2 = mFed1->registerGlobalEndpoint("ep2", "random");
+    auto& ep1 = mFed1->registerEndpoint("ep1");
+    auto& ep2 = mFed1->registerGlobalEndpoint("ep2", "random");
 
     mFed1->enterExecutingMode();
 
     EXPECT_TRUE(mFed1->getCurrentMode() == helics::Federate::Modes::EXECUTING);
 
-    auto& sv = epid.getName();
-    auto& sv2 = epid2.getName();
-    EXPECT_EQ(sv, "fed0/ep1");
-    EXPECT_EQ(sv2, "ep2");
+    auto& ep1Name = ep1.getName();
+    auto& ep2Name = ep2.getName();
+    EXPECT_EQ(ep1Name, "fed0/ep1");
+    EXPECT_EQ(ep2Name, "ep2");
 
-    EXPECT_EQ(epid.getExtractionType(), "");
-    EXPECT_EQ(epid2.getExtractionType(), "random");
+    EXPECT_EQ(ep1.getExtractionType(), "");
+    EXPECT_EQ(ep2.getExtractionType(), "random");
 
-    EXPECT_TRUE(mFed1->getEndpoint("ep1").getHandle() == epid.getHandle());
-    EXPECT_TRUE(mFed1->getEndpoint("fed0/ep1").getHandle() == epid.getHandle());
-    EXPECT_TRUE(mFed1->getEndpoint("ep2").getHandle() == epid2.getHandle());
+    EXPECT_TRUE(mFed1->getEndpoint("ep1").getHandle() == ep1.getHandle());
+    EXPECT_TRUE(mFed1->getEndpoint("fed0/ep1").getHandle() == ep1.getHandle());
+    EXPECT_TRUE(mFed1->getEndpoint("ep2").getHandle() == ep2.getHandle());
     mFed1->finalize();
 
     EXPECT_TRUE(mFed1->getCurrentMode() == helics::Federate::Modes::FINALIZE);
@@ -95,10 +99,10 @@ TEST_P(mfed_add_single_type_tests, endpoint_registration_objs)
 
     EXPECT_TRUE(mFed1->getCurrentMode() == helics::Federate::Modes::EXECUTING);
 
-    auto const& sv = epid.getName();
-    auto const& sv2 = epid2.getName();
-    EXPECT_EQ(sv, "fed0/ep1");
-    EXPECT_EQ(sv2, "ep2");
+    auto const& endpoint1Name = epid.getName();
+    auto const& endpoint2Name = epid2.getName();
+    EXPECT_EQ(endpoint1Name, "fed0/ep1");
+    EXPECT_EQ(endpoint2Name, "ep2");
 
     EXPECT_EQ(epid.getType(), "");
     EXPECT_EQ(epid2.getType(), "random");
@@ -149,11 +153,11 @@ TEST_P(mfed_add_single_type_tests, send_receive_callback)
 
     EXPECT_TRUE(rxend == epid2.getHandle());
     EXPECT_EQ(timeRx, helics::Time(1.0));
-    auto M = mFed1->getMessage(epid2);
-    ASSERT_TRUE(M);
-    ASSERT_EQ(M->data.size(), data.size());
+    auto message = mFed1->getMessage(epid2);
+    ASSERT_TRUE(message);
+    ASSERT_EQ(message->data.size(), data.size());
 
-    EXPECT_EQ(M->data[245], data[245]);
+    EXPECT_EQ(message->data[245], data[245]);
     mFed1->finalize();
 
     EXPECT_TRUE(mFed1->getCurrentMode() == helics::Federate::Modes::FINALIZE);
@@ -196,11 +200,11 @@ TEST_P(mfed_add_single_type_tests, send_receive_callback_obj)
 
     EXPECT_TRUE(rxend == ep2.getHandle());
     EXPECT_EQ(timeRx, helics::Time(1.0));
-    auto M = ep2.getMessage();
-    ASSERT_TRUE(M);
-    ASSERT_EQ(M->data.size(), data.size());
+    auto message = ep2.getMessage();
+    ASSERT_TRUE(message);
+    ASSERT_EQ(message->data.size(), data.size());
 
-    EXPECT_EQ(M->data[245], data[245]);
+    EXPECT_EQ(message->data[245], data[245]);
     mFed1->finalize();
 
     EXPECT_TRUE(mFed1->getCurrentMode() == helics::Federate::Modes::FINALIZE);
@@ -239,11 +243,11 @@ TEST_P(mfed_add_single_type_tests, send_receive_callback_obj2)
     EXPECT_TRUE(!res);
     EXPECT_TRUE(rxend == ep2.getHandle());
     EXPECT_EQ(timeRx, helics::Time(1.0));
-    auto M = ep2.getMessage();
-    ASSERT_TRUE(M);
-    ASSERT_EQ(M->data.size(), data.size());
+    auto message = ep2.getMessage();
+    ASSERT_TRUE(message);
+    ASSERT_EQ(message->data.size(), data.size());
 
-    EXPECT_EQ(M->data[245], data[245]);
+    EXPECT_EQ(message->data[245], data[245]);
     mFed1->finalize();
     EXPECT_TRUE(mFed1->getCurrentMode() == helics::Federate::Modes::FINALIZE);
 }
@@ -255,14 +259,14 @@ TEST_P(mfed_add_all_type_tests, send_receive_2fed_multisend_callback)
     auto mFed1 = GetFederateAs<helics::MessageFederate>(0);
     auto mFed2 = GetFederateAs<helics::MessageFederate>(1);
 
-    auto& epid = mFed1->registerEndpoint("ep1");
-    auto& epid2 = mFed2->registerGlobalEndpoint("ep2", "random");
+    auto& ep1 = mFed1->registerEndpoint("ep1");
+    auto& ep2 = mFed2->registerGlobalEndpoint("ep2", "random");
     std::atomic<int> e1cnt{0};
     std::atomic<int> e2cnt{0};
-    mFed1->setMessageNotificationCallback(epid,
+    mFed1->setMessageNotificationCallback(ep1,
                                           [&](const helics::Endpoint& /*unused*/,
                                               helics::Time /*unused*/) { ++e1cnt; });
-    mFed2->setMessageNotificationCallback(epid2,
+    mFed2->setMessageNotificationCallback(ep2,
                                           [&](const helics::Endpoint& /*unused*/,
                                               helics::Time /*unused*/) { ++e2cnt; });
     // mFed1->getCorePointer()->setLoggingLevel(0, 5);
@@ -279,10 +283,10 @@ TEST_P(mfed_add_all_type_tests, send_receive_2fed_multisend_callback)
     helics::SmallBuffer data2(400, std::byte{'b'});
     helics::SmallBuffer data3(300, std::byte{'c'});
     helics::SmallBuffer data4(200, std::byte{'d'});
-    epid.sendTo(data1, "ep2");
-    epid.sendTo(data2, "ep2");
-    epid.sendTo(data3, "ep2");
-    epid.sendTo(data4, "ep2");
+    ep1.sendTo(data1, "ep2");
+    ep1.sendTo(data2, "ep2");
+    ep1.sendTo(data3, "ep2");
+    ep1.sendTo(data4, "ep2");
     // move the time to 1.0
     mFed1->requestTimeAsync(1.0);
     auto gtime = mFed2->requestTime(1.0);
@@ -291,34 +295,37 @@ TEST_P(mfed_add_all_type_tests, send_receive_2fed_multisend_callback)
     EXPECT_EQ(mFed1->requestTimeComplete(), 1.0);
     EXPECT_TRUE(!mFed1->hasMessage());
 
-    EXPECT_TRUE(!mFed1->hasMessage(epid));
-    auto cnt = mFed2->pendingMessageCount(epid2);
+    EXPECT_TRUE(!mFed1->hasMessage(ep1));
+    auto cnt = mFed2->pendingMessageCount(ep2);
     EXPECT_EQ(cnt, 4);
 
-    auto M1 = mFed2->getMessage(epid2);
-    ASSERT_TRUE(M1);
-    ASSERT_EQ(M1->data.size(), data1.size());
+    cnt = mFed2->pendingMessageCount();
+    EXPECT_EQ(cnt, 4);
 
-    EXPECT_EQ(M1->data[245], data1[245]);
+    auto message1 = mFed2->getMessage(ep2);
+    ASSERT_TRUE(message1);
+    ASSERT_EQ(message1->data.size(), data1.size());
+
+    EXPECT_EQ(message1->data[245], data1[245]);
     // check the count decremented
-    cnt = mFed2->pendingMessageCount(epid2);
+    cnt = mFed2->pendingMessageCount(ep2);
     EXPECT_EQ(cnt, 3);
-    auto M2 = mFed2->getMessage();
-    ASSERT_TRUE(M2);
-    ASSERT_EQ(M2->data.size(), data2.size());
-    EXPECT_EQ(M2->data[245], data2[245]);
-    cnt = mFed2->pendingMessageCount(epid2);
+    auto message2 = mFed2->getMessage();
+    ASSERT_TRUE(message2);
+    ASSERT_EQ(message2->data.size(), data2.size());
+    EXPECT_EQ(message2->data[245], data2[245]);
+    cnt = mFed2->pendingMessageCount(ep2);
     EXPECT_EQ(cnt, 2);
 
-    auto M3 = mFed2->getMessage();
-    auto M4 = mFed2->getMessage(epid2);
-    EXPECT_EQ(M3->data.size(), data3.size());
-    EXPECT_EQ(M4->data.size(), data4.size());
+    auto message3 = mFed2->getMessage();
+    auto message4 = mFed2->getMessage(ep2);
+    EXPECT_EQ(message3->data.size(), data3.size());
+    EXPECT_EQ(message4->data.size(), data4.size());
 
-    EXPECT_EQ(M4->source, "fed0/ep1");
-    EXPECT_EQ(M4->dest, "ep2");
-    EXPECT_EQ(M4->original_source, "fed0/ep1");
-    EXPECT_EQ(M4->time, 0.0);
+    EXPECT_EQ(message4->source, "fed0/ep1");
+    EXPECT_EQ(message4->dest, "ep2");
+    EXPECT_EQ(message4->original_source, "fed0/ep1");
+    EXPECT_EQ(message4->time, 0.0);
     EXPECT_EQ(e1cnt, 0);
     EXPECT_EQ(e2cnt, 4);
     mFed1->finalizeAsync();
@@ -339,7 +346,7 @@ class PingPongFed {
     std::string name;  //!< the name of the federate
     helics::CoreType coreType;
     std::vector<std::pair<helics::Time, std::string>> triggers;
-    helics::Endpoint* ep{nullptr};
+    helics::Endpoint* ept{nullptr};
     int index{0};
 
   public:
@@ -356,24 +363,24 @@ class PingPongFed {
   private:
     void initialize()
     {
-        helics::FederateInfo fi(coreType);
-        fi.coreName = "pptest";
-        fi.coreInitString = "-f 3";
-        fi.setProperty(HELICS_PROPERTY_TIME_DELTA, delta);
+        helics::FederateInfo fedInfo(coreType);
+        fedInfo.coreName = "pptest";
+        fedInfo.coreInitString = "-f 3";
+        fedInfo.setProperty(HELICS_PROPERTY_TIME_DELTA, delta);
 #ifdef ENABLE_OUTPUT
         std::cout << std::string("about to create federate ") + name + "\n";
 #endif
-        mFed = std::make_unique<helics::MessageFederate>(name, fi);
+        mFed = std::make_unique<helics::MessageFederate>(name, fedInfo);
 #ifdef ENABLE_OUTPUT
         std::cout << std::string("registering federate ") + name + "\n";
 #endif
-        ep = &mFed->registerEndpoint("port");
+        ept = &mFed->registerEndpoint("port");
     }
 
     void processMessages(helics::Time currentTime)
     {
-        while (mFed->hasMessage(*ep)) {
-            auto mess = mFed->getMessage(*ep);
+        while (mFed->hasMessage(*ept)) {
+            auto mess = mFed->getMessage(*ept);
             auto messString = mess->data.to_string();
             if (messString == "ping") {
 #ifdef ENABLE_OUTPUT
@@ -385,7 +392,7 @@ class PingPongFed {
                 mess->source = name;
                 mess->original_source = mess->source;
                 mess->time = currentTime;
-                ep->send(std::move(mess));
+                ept->send(std::move(mess));
                 pings++;
             } else if (messString == "pong") {
                 pongs++;
@@ -407,7 +414,7 @@ class PingPongFed {
                     std::cout << name << ": send ping to " << triggers[index].second << " at time "
                               << static_cast<double>(nextTime) << '\n';
 #endif
-                    ep->sendTo("ping", triggers[index].second);
+                    ept->sendTo("ping", triggers[index].second);
                     ++index;
                     if (index >= static_cast<int>(triggers.size())) {
                         break;
@@ -444,30 +451,30 @@ TEST_P(mfed_add_type_tests, threefedPingPong)
     auto brk = AddBroker(GetParam(), "-f 3");
 
     auto crtype = helics::core::coreTypeFromString(GetParam());
-    PingPongFed p1("fedA", 0.5, crtype);
-    PingPongFed p2("fedB", 0.5, crtype);
-    PingPongFed p3("fedC", 0.5, crtype);
+    PingPongFed ping1("fedA", 0.5, crtype);
+    PingPongFed ping2("fedB", 0.5, crtype);
+    PingPongFed ping3("fedC", 0.5, crtype);
 
-    p1.addTrigger(0.5, "fedB/port");
-    p1.addTrigger(0.5, "fedC/port");
-    p1.addTrigger(3.0, "fedB/port");
-    p2.addTrigger(1.5, "fedA/port");
-    p3.addTrigger(3.0, "fedB/port");
-    p3.addTrigger(4.0, "fedA/port");
+    ping1.addTrigger(0.5, "fedB/port");
+    ping1.addTrigger(0.5, "fedC/port");
+    ping1.addTrigger(3.0, "fedB/port");
+    ping2.addTrigger(1.5, "fedA/port");
+    ping3.addTrigger(3.0, "fedB/port");
+    ping3.addTrigger(4.0, "fedA/port");
 
-    auto t1 = std::thread([&p1]() { p1.run(6.0); });
-    auto t2 = std::thread([&p2]() { p2.run(6.0); });
-    auto t3 = std::thread([&p3]() { p3.run(6.0); });
+    auto thread1 = std::thread([&ping1]() { ping1.run(6.0); });
+    auto thread2 = std::thread([&ping2]() { ping2.run(6.0); });
+    auto thread3 = std::thread([&ping3]() { ping3.run(6.0); });
 
-    t1.join();
-    t2.join();
-    t3.join();
-    EXPECT_EQ(p1.pings, 2);
-    EXPECT_EQ(p2.pings, 3);
-    EXPECT_EQ(p3.pings, 1);
-    EXPECT_EQ(p1.pongs, 3);
-    EXPECT_EQ(p2.pongs, 1);
-    EXPECT_EQ(p3.pongs, 2);
+    thread1.join();
+    thread2.join();
+    thread3.join();
+    EXPECT_EQ(ping1.pings, 2);
+    EXPECT_EQ(ping2.pings, 3);
+    EXPECT_EQ(ping3.pings, 1);
+    EXPECT_EQ(ping1.pongs, 3);
+    EXPECT_EQ(ping2.pongs, 1);
+    EXPECT_EQ(ping3.pongs, 2);
 }
 
 INSTANTIATE_TEST_SUITE_P(mfed_add_tests,
@@ -506,9 +513,9 @@ TEST_P(mfed_file_config_files, test_file_load)
     EXPECT_EQ(mFed.getName(), "messageFed");
 
     EXPECT_EQ(mFed.getEndpointCount(), 2);
-    auto id = mFed.getEndpoint("ept1");
-    EXPECT_EQ(id.getExtractionType(), "genmessage");
-    EXPECT_EQ(id.getInfo(), "this is an information string for use by the application");
+    auto& ept1 = mFed.getEndpoint("ept1");
+    EXPECT_EQ(ept1.getExtractionType(), "genmessage");
+    EXPECT_EQ(ept1.getInfo(), "this is an information string for use by the application");
 
     EXPECT_EQ(mFed.query("global_value", "global1"), "this is a global1 value");
     EXPECT_EQ(mFed.query("global_value", "global2"), "this is another global value");
@@ -531,8 +538,8 @@ TEST_P(mfed_file_filter_config_files, test_file_load_filter)
     EXPECT_EQ(mFed.getName(), "filterFed");
 
     EXPECT_EQ(mFed.getEndpointCount(), 3);
-    auto id = mFed.getEndpoint("ept1");
-    EXPECT_EQ(id.getExtractionType(), "genmessage");
+    auto& ept1 = mFed.getEndpoint("ept1");
+    EXPECT_EQ(ept1.getExtractionType(), "genmessage");
 
     EXPECT_EQ(mFed.getFilterCount(), 3);
 
@@ -543,10 +550,10 @@ TEST_P(mfed_file_filter_config_files, test_file_load_filter)
 
     EXPECT_EQ(mFed.getFilter(0).getInfo(),
               "this is an information string for use by the application");
-    auto cr = mFed.getCorePointer();
+    auto core = mFed.getCorePointer();
     mFed.disconnect();
-    cr->disconnect();
-    cr.reset();
+    core->disconnect();
+    core.reset();
 }
 
 INSTANTIATE_TEST_SUITE_P(mfed_add_tests,
@@ -568,15 +575,15 @@ TEST_F(mfed_tests, send_message1)
 
     mFed1->requestNextStep();
 
-    auto m1 = ep2.getMessage();
-    EXPECT_EQ(m1->data.size(), 26U);
+    auto message = ep2.getMessage();
+    EXPECT_EQ(message->data.size(), 26U);
 
     ep1.sendToAt(message1.c_str(), 31, "ep2", 1.7);
 
     auto res = mFed1->requestTime(2.0);
     EXPECT_EQ(res, 1.7);
-    m1 = ep2.getMessage();
-    EXPECT_EQ(m1->data.size(), 31U);
+    message = ep2.getMessage();
+    EXPECT_EQ(message->data.size(), 31U);
 
     mFed1->finalize();
 }
@@ -596,13 +603,13 @@ TEST(messageFederate, constructor1)
 
     EXPECT_FALSE(mf2.getMessage());
 
-    auto ept1 = mf2.registerEndpoint();
+    auto& ept1 = mf2.registerEndpoint();
     EXPECT_FALSE(mf2.hasMessage(ept1));
     EXPECT_EQ(mf2.pendingMessageCount(ept1), 0);
-    auto m1 = mf2.getMessage(ept1);
-    EXPECT_FALSE(m1);
+    auto message = mf2.getMessage(ept1);
+    EXPECT_FALSE(message);
 
-    EXPECT_THROW(ept1.send(std::move(m1)), helics::InvalidFunctionCall);
+    EXPECT_THROW(ept1.send(std::move(message)), helics::InvalidFunctionCall);
 
     mf2.enterExecutingMode();
     mf2.finalize();
@@ -612,10 +619,10 @@ TEST(messageFederate, constructor1)
 
 TEST(messageFederate, constructor2)
 {
-    auto cr = helics::CoreFactory::create(helics::CoreType::TEST, "--name=cb --autobroker");
-    helics::FederateInfo fi(helics::CoreType::TEST);
-    fi.setProperty(HELICS_PROPERTY_INT_LOG_LEVEL, HELICS_LOG_LEVEL_ERROR);
-    helics::MessageFederate mf1("fed1", cr, fi);
+    auto core = helics::CoreFactory::create(helics::CoreType::TEST, "--name=cb --autobroker");
+    helics::FederateInfo fedInfo(helics::CoreType::TEST);
+    fedInfo.setProperty(HELICS_PROPERTY_INT_LOG_LEVEL, HELICS_LOG_LEVEL_ERROR);
+    helics::MessageFederate mf1("fed1", core, fedInfo);
 
     mf1.registerInterfaces(std::string(TEST_DIR) + "example_message_fed_testb.json");
 
@@ -625,26 +632,26 @@ TEST(messageFederate, constructor2)
     EXPECT_NO_THROW(mf1.enterExecutingMode());
     mf1.finalize();
 
-    cr.reset();
+    core.reset();
 }
 
 TEST(messageFederate, constructor3)
 {
-    helics::CoreApp cr("--coretype=test --name=cb2 --autobroker");
+    helics::CoreApp core("--coretype=test --name=cb2 --autobroker");
 
-    helics::FederateInfo fi(helics::CoreType::TEST);
-    fi.setProperty(HELICS_PROPERTY_INT_LOG_LEVEL, HELICS_LOG_LEVEL_ERROR);
-    helics::MessageFederate mf1("fed1", cr, fi);
+    helics::FederateInfo fedInfo(helics::CoreType::TEST);
+    fedInfo.setProperty(HELICS_PROPERTY_INT_LOG_LEVEL, HELICS_LOG_LEVEL_ERROR);
+    helics::MessageFederate mf1("fed1", core, fedInfo);
 
     mf1.registerInterfaces(std::string(TEST_DIR) + "example_message_fed_testb.json");
-    EXPECT_TRUE(cr.isConnected());
+    EXPECT_TRUE(core.isConnected());
 
     mf1.registerGlobalFilter("filt1");
     mf1.registerGlobalFilter("filt2");
 
     EXPECT_NO_THROW(mf1.enterExecutingMode());
     mf1.finalize();
-    EXPECT_NO_THROW(cr.getCopyofCorePointer()->waitForDisconnect());
+    EXPECT_NO_THROW(core.getCopyofCorePointer()->waitForDisconnect());
 }
 
 TEST(messageFederate, constructor4)
@@ -849,10 +856,10 @@ TEST_F(mfed_tests, message_init_iteration)
 
     EXPECT_TRUE(ep2.hasMessage());
 
-    auto m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_LT(m->time, helics::timeZero);
+    auto message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_LT(message->time, helics::timeZero);
     }
     mFed2->enterExecutingMode();
     mFed1->enterExecutingModeComplete();
@@ -891,36 +898,37 @@ TEST_F(mfed_tests, missing_endpoint)
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     mFed1->requestTime(1.0);
 
-    auto mm = mlog.lock();
-    EXPECT_EQ(mm->size(), 1U);
-    if (!mm->empty()) {
-        EXPECT_EQ(mm->front().first, HELICS_LOG_LEVEL_WARNING);
-        EXPECT_THAT(mm->front().second, HasSubstr("ep92"));
-        EXPECT_THAT(mm->front().second, HasSubstr("ep1"));
+    auto logs = mlog.lock();
+    EXPECT_EQ(logs->size(), 1U);
+    if (!logs->empty()) {
+        EXPECT_EQ(logs->front().first, HELICS_LOG_LEVEL_WARNING);
+        EXPECT_THAT(logs->front().second, HasSubstr("ep92"));
+        EXPECT_THAT(logs->front().second, HasSubstr("ep1"));
     }
-    mm.unlock();
+    logs.unlock();
     ep2.sendTo(message1.c_str(), 26, "ep92");
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     mFed1->requestTime(2.0);
     // no warning from this one
-    mm = mlog.lock();
-    EXPECT_EQ(mm->size(), 1U);
-    mm.unlock();
+    logs = mlog.lock();
+    EXPECT_EQ(logs->size(), 1U);
+    logs.unlock();
     ep3.sendTo(message1.c_str(), 26, "ep92");
     std::this_thread::sleep_for(std::chrono::milliseconds(100));
     try {
         mFed1->requestTime(3.0);
     }
-    catch (...) {
+    catch (const helics::HelicsException&) {
+        ;
     }
-    mm = mlog.lock();
-    EXPECT_EQ(mm->size(), 2U);
-    if (!mm->empty()) {
-        EXPECT_EQ(mm->back().first, HELICS_LOG_LEVEL_ERROR);
-        EXPECT_THAT(mm->back().second, HasSubstr("ep92"));
-        EXPECT_THAT(mm->back().second, HasSubstr("ep3"));
+    logs = mlog.lock();
+    EXPECT_EQ(logs->size(), 2U);
+    if (!logs->empty()) {
+        EXPECT_EQ(logs->back().first, HELICS_LOG_LEVEL_ERROR);
+        EXPECT_THAT(logs->back().second, HasSubstr("ep92"));
+        EXPECT_THAT(logs->back().second, HasSubstr("ep3"));
     }
-    mm.unlock();
+    logs.unlock();
     mFed1->finalize();
 }
 
@@ -954,10 +962,10 @@ TEST_F(mfed_tests, targeted_endpoint_send_error1)
     EXPECT_TRUE(ep2.hasMessage());
     EXPECT_FALSE(ep4.hasMessage());
     EXPECT_FALSE(ep3.hasMessage());
-    auto m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_EQ(m->time, helics::timeZero);
+    auto message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_EQ(message->time, helics::timeZero);
     }
 
     mFed2->finalize();
@@ -994,10 +1002,10 @@ TEST_F(mfed_tests, targeted_endpoint_send_error2)
     EXPECT_TRUE(ep2.hasMessage());
     EXPECT_FALSE(ep4.hasMessage());
     EXPECT_FALSE(ep3.hasMessage());
-    auto m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_EQ(m->time, helics::timeZero);
+    auto message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_EQ(message->time, helics::timeZero);
     }
 
     mFed2->finalize();
@@ -1040,10 +1048,10 @@ TEST_F(mfed_tests, targeted_endpoint_send_error3)
     EXPECT_TRUE(ep2.hasMessage());
     EXPECT_FALSE(ep4.hasMessage());
     EXPECT_FALSE(ep3.hasMessage());
-    auto m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_EQ(m->time, helics::timeZero);
+    auto message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_EQ(message->time, helics::timeZero);
     }
 
     mFed2->finalize();
@@ -1085,44 +1093,44 @@ TEST_F(mfed_tests, targeted_endpoint_send_all)
     EXPECT_TRUE(ep2.hasMessage());
     EXPECT_TRUE(ep4.hasMessage());
     EXPECT_FALSE(ep3.hasMessage());
-    auto m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_EQ(m->time, helics::timeZero);
+    auto message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_EQ(message->time, helics::timeZero);
     }
 
-    auto m2 = ep4.getMessage();
-    if (m2) {
-        EXPECT_EQ(m2->data.size(), 26U);
-        EXPECT_EQ(m2->time, helics::timeZero);
+    auto message2 = ep4.getMessage();
+    if (message2) {
+        EXPECT_EQ(message2->data.size(), 26U);
+        EXPECT_EQ(message2->time, helics::timeZero);
     }
 
     EXPECT_TRUE(ep2.hasMessage());
     EXPECT_TRUE(ep4.hasMessage());
-    m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_EQ(m->time, helics::timeZero);
+    message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_EQ(message->time, helics::timeZero);
     }
 
-    m2 = ep4.getMessage();
-    if (m2) {
-        EXPECT_EQ(m2->data.size(), 26U);
-        EXPECT_EQ(m2->time, helics::timeZero);
+    message2 = ep4.getMessage();
+    if (message2) {
+        EXPECT_EQ(message2->data.size(), 26U);
+        EXPECT_EQ(message2->time, helics::timeZero);
     }
 
     EXPECT_TRUE(ep2.hasMessage());
     EXPECT_TRUE(ep4.hasMessage());
-    m = ep2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->data.size(), 26U);
-        EXPECT_EQ(m->time, helics::timeZero);
+    message = ep2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->data.size(), 26U);
+        EXPECT_EQ(message->time, helics::timeZero);
     }
 
-    m2 = ep4.getMessage();
-    if (m2) {
-        EXPECT_EQ(m2->data.size(), 26U);
-        EXPECT_EQ(m2->time, helics::timeZero);
+    message2 = ep4.getMessage();
+    if (message2) {
+        EXPECT_EQ(message2->data.size(), 26U);
+        EXPECT_EQ(message2->time, helics::timeZero);
     }
 
     mFed2->finalize();
@@ -1163,17 +1171,17 @@ TEST_F(mfed_tests, reentrant_fed_endpoint)
     // check the messages
     EXPECT_TRUE(ept1.hasMessage());
     EXPECT_TRUE(ept2.hasMessage());
-    auto m = ept1.getMessage();
-    if (m) {
-        EXPECT_EQ(m->to_string(), "test_from2");
+    auto message = ept1.getMessage();
+    if (message) {
+        EXPECT_EQ(message->to_string(), "test_from2");
     }
 
-    m = ept2.getMessage();
-    if (m) {
-        EXPECT_EQ(m->to_string(), "test_from1");
+    message = ept2.getMessage();
+    if (message) {
+        EXPECT_EQ(message->to_string(), "test_from1");
     }
     // close and reconnect federate
-    auto mFed2Name = mFed2->getName();
+    std::string mFed2Name = mFed2->getName();
     mFed2->disconnect();
     tres = mFed1->requestTime(helics::timeZero);
     EXPECT_LE(tres, 3.0);
@@ -1207,9 +1215,9 @@ TEST_F(mfed_tests, reentrant_fed_endpoint)
     // check the new messages
     EXPECT_TRUE(ept1.hasMessage());
 
-    m = ept1.getMessage();
-    if (m) {
-        EXPECT_EQ(m->to_string(), "test_from2_part2");
+    message = ept1.getMessage();
+    if (message) {
+        EXPECT_EQ(message->to_string(), "test_from2_part2");
     }
 
     mFed1->disconnect();
@@ -1220,9 +1228,9 @@ TEST_F(mfed_tests, reentrant_fed_endpoint)
     tres = mFed2Redo.requestNextStep();
     EXPECT_EQ(tres, 5.0);
     EXPECT_TRUE(ept2redo.hasMessage());
-    m = ept2redo.getMessage();
-    if (m) {
-        EXPECT_EQ(m->to_string(), "test_from1_part2");
+    message = ept2redo.getMessage();
+    if (message) {
+        EXPECT_EQ(message->to_string(), "test_from1_part2");
     }
     mFed2Redo.disconnect();
 }
