@@ -21,7 +21,10 @@ SPDX-License-Identifier: BSD-3-Clause
 
 #include <future>
 #include <iostream>
+#include <memory>
+#include <string>
 #include <thread>
+
 /** these test cases test out the message federates
  */
 
