@@ -11,6 +11,8 @@ SPDX-License-Identifier: BSD-3-Clause
 #include <gtest/gtest.h>
 #include <list>
 #include <set>
+#include <string>
+#include <vector>
 
 /** these test cases test out the value converters
  */
@@ -197,7 +199,7 @@ TEST(type_conversion, namedpoint_conversion)
         checkTypeConversion1(vp,
                              std::vector<std::complex<double>>{std::complex<double>(val, 0.0)}));
     EXPECT_TRUE(checkTypeConversion1(vp, true));
-    Json::Value v1;
+    nlohmann::json v1;
     v1["name"] = "point";
     v1["value"] = val;
     EXPECT_TRUE(checkTypeConversion1(vp, helics::fileops::generateJsonString(v1)));
