@@ -8,8 +8,11 @@ SPDX-License-Identifier: BSD-3-Clause
 #include <algorithm>
 #include <complex>
 #include <gtest/gtest.h>
+#include <limits>
 #include <list>
 #include <set>
+#include <string>
+#include <vector>
 
 /** these test cases test out the value converters
  */
