@@ -12,6 +12,9 @@ SPDX-License-Identifier: BSD-3-Clause
 #include <complex>
 #include <future>
 #include <iostream>
+#include <string>
+#include <utility>
+#include <vector>
 
 /** these test cases test out the value converters
  */
